summaryrefslogtreecommitdiff
path: root/include/dm/root.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/dm/root.h')
-rw-r--r--include/dm/root.h14
1 files changed, 6 insertions, 8 deletions
diff --git a/include/dm/root.h b/include/dm/root.h
index c8d629ba9b..89afbee619 100644
--- a/include/dm/root.h
+++ b/include/dm/root.h
@@ -31,15 +31,15 @@ struct global_data;
void dm_fixup_for_gd_move(struct global_data *new_gd);
/**
* dm_scan_platdata() - Scan all platform data and bind drivers
*
* This scans all available platdata and creates drivers for each
*
* @pre_reloc_only: If true, bind only drivers with the DM_FLAG_PRE_RELOC
* flag. If false bind all drivers.
* @return 0 if OK, -ve on error
*/
-int dm_scan_platdata(bool pre_reloc_only);
+int dm_scan_plat(bool pre_reloc_only);
/**
* dm_scan_fdt() - Scan the device tree and bind drivers
@@ -47,26 +47,24 @@ int dm_scan_platdata(bool pre_reloc_only);
* This scans the device tree and creates a driver for each node. Only
* the top-level subnodes are examined.
*
- * @blob: Pointer to device tree blob
* @pre_reloc_only: If true, bind only nodes with special devicetree properties,
* or drivers with the DM_FLAG_PRE_RELOC flag. If false bind all drivers.
* @return 0 if OK, -ve on error
*/
-int dm_scan_fdt(const void *blob, bool pre_reloc_only);
+int dm_scan_fdt(bool pre_reloc_only);
/**
* dm_extended_scan_fdt() - Scan the device tree and bind drivers
*
* This calls dm_scna_dft() which scans the device tree and creates a driver
* for each node. the top-level subnodes are examined and also all sub-nodes
* of "clocks" node.
*
- * @blob: Pointer to device tree blob
* @pre_reloc_only: If true, bind only nodes with special devicetree properties,
* or drivers with the DM_FLAG_PRE_RELOC flag. If false bind all drivers.
* @return 0 if OK, -ve on error
*/
-int dm_extended_scan_fdt(const void *blob, bool pre_reloc_only);
+int dm_extended_scan(bool pre_reloc_only);
/**
* dm_scan_other() - Scan for other devices
@@ -31,15 +31,15 @@ struct global_data;
void dm_fixup_for_gd_move(struct global_data *new_gd);
/**
- * dm_scan_platdata() - Scan all platform data and bind drivers
+ * dm_scan_plat() - Scan all platform data and bind drivers
*
@@ -31,15 +31,15 @@ struct global_data;
*
- * This scans all available platdata and creates drivers for each
+ * This scans all available plat and creates drivers for each
*
* @pre_reloc_only: If true, bind only drivers with the DM_FLAG_PRE_RELOC
@@ -47,26 +47,24 @@ int dm_scan_platdata(bool pre_reloc_only);
/**
- * dm_extended_scan_fdt() - Scan the device tree and bind drivers
+ * dm_extended_scan() - Scan the device tree and bind drivers
*
* This calls dm_scna_dft() which scans the device tree and creates a driver